==> dnet-openaireplus-mapping-utils-6.2.2-sources.jar: eu/dnetlib/data/transform/xml/CommonDNetXsltFunctions.java <==
package eu.dnetlib.data.transform.xml;

import java.util.List;
import java.util.Map;

import com.google.protobuf.Message.Builder;
import eu.dnetlib.data.mapreduce.util.OafRowKeyDecoder;
import eu.dnetlib.data.proto.FieldTypeProtos.KeyValue;
import eu.dnetlib.data.proto.OafProtos.Oaf;
import eu.dnetlib.data.proto.OafProtos.OafRel;
import eu.dnetlib.data.proto.RelMetadataProtos.RelMetadata;
import eu.dnetlib.data.proto.RelTypeProtos.RelType;
import eu.dnetlib.data.proto.RelTypeProtos.SubRelType;
import eu.dnetlib.data.proto.TypeProtos.Type;
import org.w3c.dom.NodeList;

/**
 * Created by claudio on 01/12/15.
 */
public class CommonDNetXsltFunctions extends AbstractDNetXsltFunctions {

	private static final int MAX_COAUTHORS = 50;

	public static String rel(
			final String source,
			final String target,
			final String relType,
			final String subRelType,
			final String relClass,
			final String provenanceAction,
			final String trust) {
		return rel(source, target, relType, subRelType, relClass, null, provenanceAction, trust, null, null);
	}

	public static String rel(
			final String source,
			final String target,
			final String relType,
			final String subRelType,
			final String relClass,
			final NodeList metadata,
			final String provenanceAction,
			final String trust) {
		return rel(source, target, relType, subRelType, relClass, metadata, provenanceAction, trust, null, null);
	}

	public static String rel(
			final String source,
			final String target,
			final String relType,
			final String subRelType,
			final String relClass,
			final NodeList metadata,
			final String provenanceAction,
			final String trust,
			final NodeList about) {
		return rel(source, target, relType, subRelType, relClass, metadata, provenanceAction, trust, about, null);
	}

	public static String rel(
			final String source,
			final String target,
			final String relType,
			final String subRelType,
			final String relClass,
			final NodeList metadata,
			final String provenanceAction,
			final String trust,
			final NodeList about,
			final Map<String, String> params) {

		ValueMap values = null;
		try {
			final String eSource = OafRowKeyDecoder.decode(source).getKey();
			final String eTarget = OafRowKeyDecoder.decode(target).getKey();

			final RelType rType = RelType.valueOf(relType);
			final SubRelType srType = SubRelType.valueOf(subRelType);

			final RelMetadata.Builder metadataBuilder = RelMetadata.newBuilder().setSemantics(getSimpleQualifier(relClass, getVocabularyName(rType)));

			final Builder subRel = getSubRelBuilder(metadataBuilder, srType, params);

			values = ValueMap.parseNodeList(metadata);

			final List<KeyValue> collectedFrom = getKeyValues(values, "collectedFrom", Type.datasource);

			final OafRel.Builder rel = getRelBuilder(rType, srType, getRel(eSource, eTarget, rType, srType, relClass, collectedFrom, false), subRel);

			final Oaf oaf = getOaf(rel, getDataInfo(about, provenanceAction, trust, false, false));
			return base64(oaf.toByteArray());
		} catch (Exception e) {
			e.printStackTrace(System.err);
			throw new RuntimeException(e);
		}
	}

}

==> dnet-openaireplus-mapping-utils-6.2.12-20180924.135636-34-sources.jar: eu/dnetlib/data/transform/xml/CommonDNetXsltFunctions.java <==
package eu.dnetlib.data.transform.xml;

import java.util.List;
import java.util.Map;

import com.google.common.collect.Lists;
import com.google.protobuf.Message.Builder;
import eu.dnetlib.data.mapreduce.util.OafRowKeyDecoder;
import eu.dnetlib.data.proto.FieldTypeProtos.KeyValue;
import eu.dnetlib.data.proto.OafProtos.Oaf;
import eu.dnetlib.data.proto.OafProtos.OafRel;
import eu.dnetlib.data.proto.RelMetadataProtos.RelMetadata;
import eu.dnetlib.data.proto.RelTypeProtos.RelType;
import eu.dnetlib.data.proto.RelTypeProtos.SubRelType;
import eu.dnetlib.data.proto.TypeProtos.Type;
import org.w3c.dom.NodeList;

/**
 * Created by claudio on 01/12/15.
 */
public class CommonDNetXsltFunctions extends AbstractDNetXsltFunctions {

	private static final int MAX_COAUTHORS = 50;

	public static String rel(
			final String source,
			final String target,
			final String relType,
			final String subRelType,
			final String relClass,
			final String provenanceAction,
			final String trust) {
		return rel(source, target, relType, subRelType, relClass, null, provenanceAction, trust, null, null);
	}

	public static String rel(
			final String source,
			final String target,
			final String relType,
			final String subRelType,
			final String relClass,
			final NodeList metadata,
			final String provenanceAction,
			final String trust) {
		return rel(source, target, relType, subRelType, relClass, metadata, provenanceAction, trust, null, null);
	}

	public static String rel(
			final String source,
			final String target,
			final String relType,
			final String subRelType,
			final String relClass,
			final NodeList metadata,
			final String provenanceAction,
			final String trust,
			final NodeList about) {
		return rel(source, target, relType, subRelType, relClass, metadata, provenanceAction, trust, about, null);
	}

	public static String rel(
			final String source,
			final String target,
			final String relType,
			final String subRelType,
			final String relClass,
			final NodeList metadata,
			final String provenanceAction,
			final String trust,
			final NodeList about,
			final Map<String, String> params) {

		ValueMap values = null;
		List<KeyValue> collectedFrom = Lists.newArrayList();
		try {
			final String eSource = OafRowKeyDecoder.decode(source).getKey();
			final String eTarget = OafRowKeyDecoder.decode(target).getKey();

			final RelType rType = RelType.valueOf(relType);
			final SubRelType srType = SubRelType.valueOf(subRelType);

			final RelMetadata.Builder metadataBuilder = RelMetadata.newBuilder().setSemantics(getSimpleQualifier(relClass, getVocabularyName(rType)));

			final Builder subRel = getSubRelBuilder(metadataBuilder, srType, params);

			if(metadata != null) {
				values = ValueMap.parseNodeList(metadata);
				collectedFrom = getKeyValues(values, "collectedFrom", Type.datasource);
			}

			final OafRel.Builder rel = getRelBuilder(rType, srType, getRel(eSource, eTarget, rType, srType, relClass, collectedFrom, false), subRel);

			final Oaf oaf = getOaf(rel, getDataInfo(about, provenanceAction, trust, false, false));
			return base64(oaf.toByteArray());
		} catch (Exception e) {
			e.printStackTrace(System.err);
			throw new RuntimeException(e);
		}
	}

}
